CREATE INDEX index_0_0 ON py_phrase_0(s0, y0);
CREATE INDEX index_1_0 ON py_phrase_1(s0, y0, s1, y1);
CREATE INDEX index_1_1 ON py_phrase_1(s0, s1, y1);
CREATE INDEX index_2_0 ON py_phrase_2(s0, y0, s1, y1, s2, y2);
CREATE INDEX index_2_1 ON py_phrase_2(s0, s1, s2, y2);
CREATE INDEX index_3_0 ON py_phrase_3(s0, y0, s1, y1, s2, y2);
CREATE INDEX index_3_1 ON py_phrase_3(s0, s1, s2, y2);
CREATE INDEX index_4_0 ON py_phrase_4(s0, y0, s1, y1, s2, y2);
CREATE INDEX index_4_1 ON py_phrase_4(s0, s1, s2, y2);
CREATE INDEX index_5_0 ON py_phrase_5(s0, y0, s1, y1, s2, y2);
CREATE INDEX index_5_1 ON py_phrase_5(s0, s1, s2, y2);
CREATE INDEX index_6_0 ON py_phrase_6(s0, y0, s1, y1, s2, y2);
CREATE INDEX index_6_1 ON py_phrase_6(s0, s1, s2, y2);
CREATE INDEX index_7_0 ON py_phrase_7(s0, y0, s1, y1, s2, y2);
CREATE INDEX index_7_1 ON py_phrase_7(s0, s1, s2, y2);
CREATE INDEX index_8_0 ON py_phrase_8(s0, y0, s1, y1, s2, y2);
CREATE INDEX index_8_1 ON py_phrase_8(s0, s1, s2, y2);
CREATE INDEX index_9_0 ON py_phrase_9(s0, y0, s1, y1, s2, y2);
CREATE INDEX index_9_1 ON py_phrase_9(s0, s1, s2, y2);
CREATE INDEX index_10_0 ON py_phrase_10(s0, y0, s1, y1, s2, y2);
CREATE INDEX index_10_1 ON py_phrase_10(s0, s1, s2, y2);
CREATE INDEX index_11_0 ON py_phrase_11(s0, y0, s1, y1, s2, y2);
CREATE INDEX index_11_1 ON py_phrase_11(s0, s1, s2, y2);
CREATE INDEX index_12_0 ON py_phrase_12(s0, y0, s1, y1, s2, y2);
CREATE INDEX index_12_1 ON py_phrase_12(s0, s1, s2, y2);
CREATE INDEX index_13_0 ON py_phrase_13(s0, y0, s1, y1, s2, y2);
CREATE INDEX index_13_1 ON py_phrase_13(s0, s1, s2, y2);
CREATE INDEX index_14_0 ON py_phrase_14(s0, y0, s1, y1, s2, y2);
CREATE INDEX index_14_1 ON py_phrase_14(s0, s1, s2, y2);
CREATE INDEX index_15_0 ON py_phrase_15(s0, y0, s1, y1, s2, y2);
CREATE INDEX index_15_1 ON py_phrase_15(s0, s1, s2, y2);
